----------------------------------
--      Module Declaration      --
----------------------------------

local boss = BB["Svala Sorrowgrave"]
local mod = BigWigs:New(boss, tonumber(("$Revision: 591 $"):sub(12, -3)))
if not mod then return end
mod.partyContent = true
mod.otherMenu = "Howling Fjord"
mod.zonename = BZ["Utgarde Pinnacle"]
mod.enabletrigger = boss 
mod.guid = 26668
mod.toggleOptions = {"ritual", "ritualbars", "preparation", "bosskill"}

--------------------------------
--       Are you local?       --
--------------------------------

local started = nil

--------------------------------
--        Localization        --
--------------------------------

local L = AceLibrary("AceLocale-2.2"):new("BigWigs"..boss)

L:RegisterTranslations("enUS", function() return {
	cmd = "Svala",
	preparation = "Ritual Preparation",
	preparation_desc = "Warn who has Ritual Preparation.",
	preparation_message = "%s: %s",
	ritual = "Ritual of the Sword",
	ritualbars = "Ritual Bars",
	ritualbars_desc = "Show bars for the duration of the Ritual of the Sword and its cooldown.",
	ritualcooldown_bar = "Ritual cooldown",
	ritualcooldown_message = "Ritual cooldown passed",
	ritual_desc = "Warn for the casting of Ritual of the Sword and its cooldown.",
}

end )

L:RegisterTranslations("deDE", function() return {
	cmd = "Svala",
	preparation = "Ritualvorbereitung",
	preparation_desc = "Warnung wer sich in der Ritualvorbereitung befindet.",
	preparation_message = "%s: %s",
	ritual = "Ritual des Schwertes",
	ritualbars = "Ritual-Leisten",
	ritualbars_desc = "Leisten für die Dauer von Ritual des Schwertes und dessen Cooldown anzeigen.",
	ritualcooldown_bar = "Ritual-Cooldown",
	ritualcooldown_message = "Ritual-Cooldown abgelaufen!",
	ritual_desc = "Warnungen für das Zaubern von Ritual des Schwertes, sowie dessen Cooldowns.",
}

end )

L:RegisterTranslations("esES", function() return {
}

end )

L:RegisterTranslations("esMX", function() return {
}

end )

L:RegisterTranslations("frFR", function() return {
	cmd = "Svala",
	preparation = "Préparation du rituel",
	preparation_desc = "Prévient quand un joueur subit les effets de la Préparation du rituel.",
	preparation_message = "%s : %s",
	ritual = "Rituel de l'Epée",
	ritualbars = "Rituel de l'Epée - Barres",
	ritualbars_desc = "Affiche des barres indiquant la durée du Rituel de l'Epée ainsi que son temps de recharge.",
	ritualcooldown_bar = "Recharge Rituel",
	ritualcooldown_message = "Temps de recharge du Rituel terminé",
	ritual_desc = "Prévient quand un Rituel de l'Epée est incanté.",
}

end )

L:RegisterTranslations("koKR", function() return {
	cmd = "스발라",
	preparation = "검의 의식 대상자",
	preparation_desc = "검의 의식에 걸린 플레이어를 알립니다.",
	preparation_message = "%s: %s",
	ritual = "검의 의식",
	ritualbars = "검의 의식 바",
	ritualbars_desc = "검의 의식의 지속 바와 재사용 대기시간 바를 표시합니다.",
	ritualcooldown_bar = "의식 대기시간",
	ritualcooldown_message = "의식 대기시간 종료",
	ritual_desc = "검의 의식 시전을 알립니다.",
}

end )

L:RegisterTranslations("ruRU", function() return {
	cmd = "Svala",
	preparation = "Подготовка ритуала",
	preparation_desc = "Сообщать, кого подготовливают к ритуалу.",
	preparation_message = "%s: %s",
	ritual = "Ритуал меча",
	ritualbars = "Полоса ритуала",
	ritualbars_desc = "Отображать полосы продолжительности Ритуала Меча и его перезарядки.",
	ritualcooldown_bar = "Перезарядка ритуала",
	ritualcooldown_message = "Перезарядка ритуала закончена!",
	ritual_desc = "Предупреждать о применении ритуала меча.",
}

end )

L:RegisterTranslations("zhCN", function() return {
	preparation = "准备仪式",
	preparation_desc = "当玩家中了准备仪式时发出警报。",
	preparation_message = "%s：>%s<！",
	ritual = "利剑仪祭",
	ritualbars = "利剑仪祭计时条",
	ritualbars_desc = "当利剑仪祭持续和冷却时显示计时条。",
	ritualcooldown_bar = "<利剑仪祭 冷却>",
	ritualcooldown_message = "利剑仪祭 冷却结束！",
	ritual_desc = "当正在施放利剑仪祭或冷却时发出警报。",
}

end )

L:RegisterTranslations("zhTW", function() return {
	cmd = "司瓦拉",
	preparation = "準備儀式",
	preparation_desc = "當玩家中了準備儀式時發出警報。",
	preparation_message = "%s：>%s<！",
	ritual = "劍之儀式",
	ritualbars = "劍之儀式計時條",
	ritualbars_desc = "當劍之儀式持續和冷卻時顯示計時條。",
	ritualcooldown_bar = "<劍之儀式 冷卻>",
	ritualcooldown_message = "劍之儀式 冷卻結束！",
	ritual_desc = "當正在施放劍之儀式或冷卻時發出警報。",
}

end )

----------------------------------
--        Initialization        --
----------------------------------

function mod:OnEnable()
	self:AddCombatListener("SPELL_CAST_START", "Ritual", 48276)
	self:AddCombatListener("SPELL_AURA_APPLIED", "Preparation", 48267)
	self:AddCombatListener("UNIT_DIED", "BossDeath")

	started = nil
end

----------------------------------
--        Event Handlers        --
----------------------------------

function mod:Ritual(_, spellId, _, _, spellName)
	if self.db.profile.ritual then
		self:IfMessage(L["ritual"], "Urgent", spellId)
		self:DelayedMessage(36, L["ritualcooldown_message"], "Attention")
	end
	if self.db.profile.ritualbars then
		self:Bar(spellName, 26, spellId)
		self:Bar(L["ritualcooldown_bar"], 36, spellId)
	end
end

function mod:Preparation(player, spellId, _, _, spellName)
	if self.db.profile.preparation then
		self:IfMessage(L["preparation_message"]:format(spellName, player), "Attention", spellId)
	end
end
